import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  BedrockAgentRuntimeClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../BedrockAgentRuntimeClient";
import {
  GetFlowExecutionRequest,
  GetFlowExecutionResponse,
} from "../models/models_0";
export { __MetadataBearer };
export { $Command };
export interface GetFlowExecutionCommandInput extends GetFlowExecutionRequest {}
export interface GetFlowExecutionCommandOutput
  extends GetFlowExecutionResponse,
    __MetadataBearer {}
declare const GetFlowExecutionCommand_base: {
  new (
    input: GetFlowExecutionCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    GetFlowExecutionCommandInput,
    GetFlowExecutionCommandOutput,
    BedrockAgentRuntimeClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: GetFlowExecutionCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    GetFlowExecutionCommandInput,
    GetFlowExecutionCommandOutput,
    BedrockAgentRuntimeClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class GetFlowExecutionCommand extends GetFlowExecutionCommand_base {
  protected static __types: {
    api: {
      input: GetFlowExecutionRequest;
      output: GetFlowExecutionResponse;
    };
    sdk: {
      input: GetFlowExecutionCommandInput;
      output: GetFlowExecutionCommandOutput;
    };
  };
}
