import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  BedrockAgentRuntimeClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../BedrockAgentRuntimeClient";
import {
  DeleteAgentMemoryRequest,
  DeleteAgentMemoryResponse,
} from "../models/models_0";
export { __MetadataBearer };
export { $Command };
export interface DeleteAgentMemoryCommandInput
  extends DeleteAgentMemoryRequest {}
export interface DeleteAgentMemoryCommandOutput
  extends DeleteAgentMemoryResponse,
    __MetadataBearer {}
declare const DeleteAgentMemoryCommand_base: {
  new (
    input: DeleteAgentMemoryCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    DeleteAgentMemoryCommandInput,
    DeleteAgentMemoryCommandOutput,
    BedrockAgentRuntimeClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: DeleteAgentMemoryCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    DeleteAgentMemoryCommandInput,
    DeleteAgentMemoryCommandOutput,
    BedrockAgentRuntimeClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class DeleteAgentMemoryCommand extends DeleteAgentMemoryCommand_base {
  protected static __types: {
    api: {
      input: DeleteAgentMemoryRequest;
      output: {};
    };
    sdk: {
      input: DeleteAgentMemoryCommandInput;
      output: DeleteAgentMemoryCommandOutput;
    };
  };
}
