import type { PaginationConfiguration } from "@smithy/types";
import { BedrockAgentRuntimeClient } from "../BedrockAgentRuntimeClient";
/**
 * @public
 */
export interface BedrockAgentRuntimePaginationConfiguration extends PaginationConfiguration {
    client: BedrockAgentRuntimeClient;
}
