import { PaginationConfiguration } from "@smithy/types";
import { BedrockAgentRuntimeClient } from "../BedrockAgentRuntimeClient";
export interface BedrockAgentRuntimePaginationConfiguration
  extends PaginationConfiguration {
  client: BedrockAgentRuntimeClient;
}
