export declare const CustomControlMethod: {
  readonly RETURN_CONTROL: "RETURN_CONTROL";
};
export type CustomControlMethod =
  (typeof CustomControlMethod)[keyof typeof CustomControlMethod];
export declare const ExecutionType: {
  readonly LAMBDA: "LAMBDA";
  readonly RETURN_CONTROL: "RETURN_CONTROL";
};
export type ExecutionType = (typeof ExecutionType)[keyof typeof ExecutionType];
export declare const ActionGroupSignature: {
  readonly AMAZON_CODEINTERPRETER: "AMAZON.CodeInterpreter";
  readonly AMAZON_USERINPUT: "AMAZON.UserInput";
  readonly ANTHROPIC_BASH: "ANTHROPIC.Bash";
  readonly ANTHROPIC_COMPUTER: "ANTHROPIC.Computer";
  readonly ANTHROPIC_TEXTEDITOR: "ANTHROPIC.TextEditor";
};
export type ActionGroupSignature =
  (typeof ActionGroupSignature)[keyof typeof ActionGroupSignature];
export declare const ActionInvocationType: {
  readonly RESULT: "RESULT";
  readonly USER_CONFIRMATION: "USER_CONFIRMATION";
  readonly USER_CONFIRMATION_AND_RESULT: "USER_CONFIRMATION_AND_RESULT";
};
export type ActionInvocationType =
  (typeof ActionInvocationType)[keyof typeof ActionInvocationType];
export declare const ParameterType: {
  readonly ARRAY: "array";
  readonly BOOLEAN: "boolean";
  readonly INTEGER: "integer";
  readonly NUMBER: "number";
  readonly STRING: "string";
};
export type ParameterType = (typeof ParameterType)[keyof typeof ParameterType];
export declare const RequireConfirmation: {
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type RequireConfirmation =
  (typeof RequireConfirmation)[keyof typeof RequireConfirmation];
export declare const AgentCollaboration: {
  readonly DISABLED: "DISABLED";
  readonly SUPERVISOR: "SUPERVISOR";
  readonly SUPERVISOR_ROUTER: "SUPERVISOR_ROUTER";
};
export type AgentCollaboration =
  (typeof AgentCollaboration)[keyof typeof AgentCollaboration];
export declare const ConfirmationState: {
  readonly CONFIRM: "CONFIRM";
  readonly DENY: "DENY";
};
export type ConfirmationState =
  (typeof ConfirmationState)[keyof typeof ConfirmationState];
export declare const ImageInputFormat: {
  readonly GIF: "gif";
  readonly JPEG: "jpeg";
  readonly PNG: "png";
  readonly WEBP: "webp";
};
export type ImageInputFormat =
  (typeof ImageInputFormat)[keyof typeof ImageInputFormat];
export declare const ResponseState: {
  readonly FAILURE: "FAILURE";
  readonly REPROMPT: "REPROMPT";
};
export type ResponseState = (typeof ResponseState)[keyof typeof ResponseState];
export declare const PayloadType: {
  readonly RETURN_CONTROL: "RETURN_CONTROL";
  readonly TEXT: "TEXT";
};
export type PayloadType = (typeof PayloadType)[keyof typeof PayloadType];
export declare const GuardrailAction: {
  readonly INTERVENED: "INTERVENED";
  readonly NONE: "NONE";
};
export type GuardrailAction =
  (typeof GuardrailAction)[keyof typeof GuardrailAction];
export declare const GuardrailContentPolicyAction: {
  readonly BLOCKED: "BLOCKED";
};
export type GuardrailContentPolicyAction =
  (typeof GuardrailContentPolicyAction)[keyof typeof GuardrailContentPolicyAction];
export declare const GuardrailContentFilterConfidence: {
  readonly HIGH: "HIGH";
  readonly LOW: "LOW";
  readonly MEDIUM: "MEDIUM";
  readonly NONE: "NONE";
};
export type GuardrailContentFilterConfidence =
  (typeof GuardrailContentFilterConfidence)[keyof typeof GuardrailContentFilterConfidence];
export declare const GuardrailContentFilterType: {
  readonly HATE: "HATE";
  readonly INSULTS: "INSULTS";
  readonly MISCONDUCT: "MISCONDUCT";
  readonly PROMPT_ATTACK: "PROMPT_ATTACK";
  readonly SEXUAL: "SEXUAL";
  readonly VIOLENCE: "VIOLENCE";
};
export type GuardrailContentFilterType =
  (typeof GuardrailContentFilterType)[keyof typeof GuardrailContentFilterType];
export declare const GuardrailSensitiveInformationPolicyAction: {
  readonly ANONYMIZED: "ANONYMIZED";
  readonly BLOCKED: "BLOCKED";
};
export type GuardrailSensitiveInformationPolicyAction =
  (typeof GuardrailSensitiveInformationPolicyAction)[keyof typeof GuardrailSensitiveInformationPolicyAction];
export declare const GuardrailPiiEntityType: {
  readonly ADDRESS: "ADDRESS";
  readonly AGE: "AGE";
  readonly AWS_ACCESS_KEY: "AWS_ACCESS_KEY";
  readonly AWS_SECRET_KEY: "AWS_SECRET_KEY";
  readonly CA_HEALTH_NUMBER: "CA_HEALTH_NUMBER";
  readonly CA_SOCIAL_INSURANCE_NUMBER: "CA_SOCIAL_INSURANCE_NUMBER";
  readonly CREDIT_DEBIT_CARD_CVV: "CREDIT_DEBIT_CARD_CVV";
  readonly CREDIT_DEBIT_CARD_EXPIRY: "CREDIT_DEBIT_CARD_EXPIRY";
  readonly CREDIT_DEBIT_CARD_NUMBER: "CREDIT_DEBIT_CARD_NUMBER";
  readonly DRIVER_ID: "DRIVER_ID";
  readonly EMAIL: "EMAIL";
  readonly INTERNATIONAL_BANK_ACCOUNT_NUMBER: "INTERNATIONAL_BANK_ACCOUNT_NUMBER";
  readonly IP_ADDRESS: "IP_ADDRESS";
  readonly LICENSE_PLATE: "LICENSE_PLATE";
  readonly MAC_ADDRESS: "MAC_ADDRESS";
  readonly NAME: "NAME";
  readonly PASSWORD: "PASSWORD";
  readonly PHONE: "PHONE";
  readonly PIN: "PIN";
  readonly SWIFT_CODE: "SWIFT_CODE";
  readonly UK_NATIONAL_HEALTH_SERVICE_NUMBER: "UK_NATIONAL_HEALTH_SERVICE_NUMBER";
  readonly UK_NATIONAL_INSURANCE_NUMBER: "UK_NATIONAL_INSURANCE_NUMBER";
  readonly UK_UNIQUE_TAXPAYER_REFERENCE_NUMBER: "UK_UNIQUE_TAXPAYER_REFERENCE_NUMBER";
  readonly URL: "URL";
  readonly USERNAME: "USERNAME";
  readonly US_BANK_ACCOUNT_NUMBER: "US_BANK_ACCOUNT_NUMBER";
  readonly US_BANK_ROUTING_NUMBER: "US_BANK_ROUTING_NUMBER";
  readonly US_INDIVIDUAL_TAX_IDENTIFICATION_NUMBER: "US_INDIVIDUAL_TAX_IDENTIFICATION_NUMBER";
  readonly US_PASSPORT_NUMBER: "US_PASSPORT_NUMBER";
  readonly US_SOCIAL_SECURITY_NUMBER: "US_SOCIAL_SECURITY_NUMBER";
  readonly VEHICLE_IDENTIFICATION_NUMBER: "VEHICLE_IDENTIFICATION_NUMBER";
};
export type GuardrailPiiEntityType =
  (typeof GuardrailPiiEntityType)[keyof typeof GuardrailPiiEntityType];
export declare const GuardrailTopicPolicyAction: {
  readonly BLOCKED: "BLOCKED";
};
export type GuardrailTopicPolicyAction =
  (typeof GuardrailTopicPolicyAction)[keyof typeof GuardrailTopicPolicyAction];
export declare const GuardrailTopicType: {
  readonly DENY: "DENY";
};
export type GuardrailTopicType =
  (typeof GuardrailTopicType)[keyof typeof GuardrailTopicType];
export declare const GuardrailWordPolicyAction: {
  readonly BLOCKED: "BLOCKED";
};
export type GuardrailWordPolicyAction =
  (typeof GuardrailWordPolicyAction)[keyof typeof GuardrailWordPolicyAction];
export declare const GuardrailManagedWordType: {
  readonly PROFANITY: "PROFANITY";
};
export type GuardrailManagedWordType =
  (typeof GuardrailManagedWordType)[keyof typeof GuardrailManagedWordType];
export declare const InvocationType: {
  readonly ACTION_GROUP: "ACTION_GROUP";
  readonly ACTION_GROUP_CODE_INTERPRETER: "ACTION_GROUP_CODE_INTERPRETER";
  readonly AGENT_COLLABORATOR: "AGENT_COLLABORATOR";
  readonly FINISH: "FINISH";
  readonly KNOWLEDGE_BASE: "KNOWLEDGE_BASE";
};
export type InvocationType =
  (typeof InvocationType)[keyof typeof InvocationType];
export declare const CreationMode: {
  readonly DEFAULT: "DEFAULT";
  readonly OVERRIDDEN: "OVERRIDDEN";
};
export type CreationMode = (typeof CreationMode)[keyof typeof CreationMode];
export declare const PromptType: {
  readonly KNOWLEDGE_BASE_RESPONSE_GENERATION: "KNOWLEDGE_BASE_RESPONSE_GENERATION";
  readonly ORCHESTRATION: "ORCHESTRATION";
  readonly POST_PROCESSING: "POST_PROCESSING";
  readonly PRE_PROCESSING: "PRE_PROCESSING";
  readonly ROUTING_CLASSIFIER: "ROUTING_CLASSIFIER";
};
export type PromptType = (typeof PromptType)[keyof typeof PromptType];
export declare const RetrievalResultContentColumnType: {
  readonly BLOB: "BLOB";
  readonly BOOLEAN: "BOOLEAN";
  readonly DOUBLE: "DOUBLE";
  readonly LONG: "LONG";
  readonly NULL: "NULL";
  readonly STRING: "STRING";
};
export type RetrievalResultContentColumnType =
  (typeof RetrievalResultContentColumnType)[keyof typeof RetrievalResultContentColumnType];
export declare const RetrievalResultContentType: {
  readonly AUDIO: "AUDIO";
  readonly IMAGE: "IMAGE";
  readonly ROW: "ROW";
  readonly TEXT: "TEXT";
  readonly VIDEO: "VIDEO";
};
export type RetrievalResultContentType =
  (typeof RetrievalResultContentType)[keyof typeof RetrievalResultContentType];
export declare const RetrievalResultLocationType: {
  readonly CONFLUENCE: "CONFLUENCE";
  readonly CUSTOM: "CUSTOM";
  readonly KENDRA: "KENDRA";
  readonly S3: "S3";
  readonly SALESFORCE: "SALESFORCE";
  readonly SHAREPOINT: "SHAREPOINT";
  readonly SQL: "SQL";
  readonly WEB: "WEB";
};
export type RetrievalResultLocationType =
  (typeof RetrievalResultLocationType)[keyof typeof RetrievalResultLocationType];
export declare const Source: {
  readonly ACTION_GROUP: "ACTION_GROUP";
  readonly KNOWLEDGE_BASE: "KNOWLEDGE_BASE";
  readonly PARSER: "PARSER";
};
export type Source = (typeof Source)[keyof typeof Source];
export declare const Type: {
  readonly ACTION_GROUP: "ACTION_GROUP";
  readonly AGENT_COLLABORATOR: "AGENT_COLLABORATOR";
  readonly ASK_USER: "ASK_USER";
  readonly FINISH: "FINISH";
  readonly KNOWLEDGE_BASE: "KNOWLEDGE_BASE";
  readonly REPROMPT: "REPROMPT";
};
export type Type = (typeof Type)[keyof typeof Type];
export declare const FlowExecutionErrorType: {
  readonly TIMED_OUT: "ExecutionTimedOut";
};
export type FlowExecutionErrorType =
  (typeof FlowExecutionErrorType)[keyof typeof FlowExecutionErrorType];
export declare const FlowExecutionStatus: {
  readonly ABORTED: "Aborted";
  readonly FAILED: "Failed";
  readonly RUNNING: "Running";
  readonly SUCCEEDED: "Succeeded";
  readonly TIMED_OUT: "TimedOut";
};
export type FlowExecutionStatus =
  (typeof FlowExecutionStatus)[keyof typeof FlowExecutionStatus];
export declare const FlowExecutionEventType: {
  readonly FLOW: "Flow";
  readonly NODE: "Node";
};
export type FlowExecutionEventType =
  (typeof FlowExecutionEventType)[keyof typeof FlowExecutionEventType];
export declare const FlowErrorCode: {
  readonly INTERNAL_SERVER: "INTERNAL_SERVER";
  readonly NODE_EXECUTION_FAILED: "NODE_EXECUTION_FAILED";
  readonly VALIDATION: "VALIDATION";
};
export type FlowErrorCode = (typeof FlowErrorCode)[keyof typeof FlowErrorCode];
export declare const NodeErrorCode: {
  readonly BAD_GATEWAY: "BAD_GATEWAY";
  readonly DEPENDENCY_FAILED: "DEPENDENCY_FAILED";
  readonly INTERNAL_SERVER: "INTERNAL_SERVER";
  readonly VALIDATION: "VALIDATION";
};
export type NodeErrorCode = (typeof NodeErrorCode)[keyof typeof NodeErrorCode];
export declare const FlowNodeInputCategory: {
  readonly EXIT_LOOP: "ExitLoop";
  readonly LOOP_CONDITION: "LoopCondition";
  readonly RETURN_VALUE_TO_LOOP_START: "ReturnValueToLoopStart";
};
export type FlowNodeInputCategory =
  (typeof FlowNodeInputCategory)[keyof typeof FlowNodeInputCategory];
export declare const FlowControlNodeType: {
  readonly ITERATOR: "Iterator";
  readonly LOOP: "Loop";
};
export type FlowControlNodeType =
  (typeof FlowControlNodeType)[keyof typeof FlowControlNodeType];
export declare const FlowNodeIODataType: {
  readonly ARRAY: "Array";
  readonly BOOLEAN: "Boolean";
  readonly NUMBER: "Number";
  readonly OBJECT: "Object";
  readonly STRING: "String";
};
export type FlowNodeIODataType =
  (typeof FlowNodeIODataType)[keyof typeof FlowNodeIODataType];
export declare const PerformanceConfigLatency: {
  readonly OPTIMIZED: "optimized";
  readonly STANDARD: "standard";
};
export type PerformanceConfigLatency =
  (typeof PerformanceConfigLatency)[keyof typeof PerformanceConfigLatency];
export declare const FlowCompletionReason: {
  readonly INPUT_REQUIRED: "INPUT_REQUIRED";
  readonly SUCCESS: "SUCCESS";
};
export type FlowCompletionReason =
  (typeof FlowCompletionReason)[keyof typeof FlowCompletionReason];
export declare const NodeType: {
  readonly CONDITION_NODE: "ConditionNode";
  readonly FLOW_INPUT_NODE: "FlowInputNode";
  readonly FLOW_OUTPUT_NODE: "FlowOutputNode";
  readonly KNOWLEDGE_BASE_NODE: "KnowledgeBaseNode";
  readonly LAMBDA_FUNCTION_NODE: "LambdaFunctionNode";
  readonly LEX_NODE: "LexNode";
  readonly PROMPT_NODE: "PromptNode";
};
export type NodeType = (typeof NodeType)[keyof typeof NodeType];
export declare const InputQueryType: {
  readonly TEXT: "TEXT";
};
export type InputQueryType =
  (typeof InputQueryType)[keyof typeof InputQueryType];
export declare const QueryTransformationMode: {
  readonly TEXT_TO_SQL: "TEXT_TO_SQL";
};
export type QueryTransformationMode =
  (typeof QueryTransformationMode)[keyof typeof QueryTransformationMode];
export declare const TextToSqlConfigurationType: {
  readonly KNOWLEDGE_BASE: "KNOWLEDGE_BASE";
};
export type TextToSqlConfigurationType =
  (typeof TextToSqlConfigurationType)[keyof typeof TextToSqlConfigurationType];
export declare const GeneratedQueryType: {
  readonly REDSHIFT_SQL: "REDSHIFT_SQL";
};
export type GeneratedQueryType =
  (typeof GeneratedQueryType)[keyof typeof GeneratedQueryType];
export declare const ConversationRole: {
  readonly ASSISTANT: "assistant";
  readonly USER: "user";
};
export type ConversationRole =
  (typeof ConversationRole)[keyof typeof ConversationRole];
export declare const FileSourceType: {
  readonly BYTE_CONTENT: "BYTE_CONTENT";
  readonly S3: "S3";
};
export type FileSourceType =
  (typeof FileSourceType)[keyof typeof FileSourceType];
export declare const FileUseCase: {
  readonly CHAT: "CHAT";
  readonly CODE_INTERPRETER: "CODE_INTERPRETER";
};
export type FileUseCase = (typeof FileUseCase)[keyof typeof FileUseCase];
export declare const AttributeType: {
  readonly BOOLEAN: "BOOLEAN";
  readonly NUMBER: "NUMBER";
  readonly STRING: "STRING";
  readonly STRING_LIST: "STRING_LIST";
};
export type AttributeType = (typeof AttributeType)[keyof typeof AttributeType];
export declare const SearchType: {
  readonly HYBRID: "HYBRID";
  readonly SEMANTIC: "SEMANTIC";
};
export type SearchType = (typeof SearchType)[keyof typeof SearchType];
export declare const RerankingMetadataSelectionMode: {
  readonly ALL: "ALL";
  readonly SELECTIVE: "SELECTIVE";
};
export type RerankingMetadataSelectionMode =
  (typeof RerankingMetadataSelectionMode)[keyof typeof RerankingMetadataSelectionMode];
export declare const VectorSearchRerankingConfigurationType: {
  readonly BEDROCK_RERANKING_MODEL: "BEDROCK_RERANKING_MODEL";
};
export type VectorSearchRerankingConfigurationType =
  (typeof VectorSearchRerankingConfigurationType)[keyof typeof VectorSearchRerankingConfigurationType];
export declare const RelayConversationHistory: {
  readonly DISABLED: "DISABLED";
  readonly TO_COLLABORATOR: "TO_COLLABORATOR";
};
export type RelayConversationHistory =
  (typeof RelayConversationHistory)[keyof typeof RelayConversationHistory];
export declare const PromptState: {
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type PromptState = (typeof PromptState)[keyof typeof PromptState];
export declare const OrchestrationType: {
  readonly CUSTOM_ORCHESTRATION: "CUSTOM_ORCHESTRATION";
  readonly DEFAULT: "DEFAULT";
};
export type OrchestrationType =
  (typeof OrchestrationType)[keyof typeof OrchestrationType];
export declare const MemoryType: {
  readonly SESSION_SUMMARY: "SESSION_SUMMARY";
};
export type MemoryType = (typeof MemoryType)[keyof typeof MemoryType];
export declare const RerankQueryContentType: {
  readonly TEXT: "TEXT";
};
export type RerankQueryContentType =
  (typeof RerankQueryContentType)[keyof typeof RerankQueryContentType];
export declare const RerankingConfigurationType: {
  readonly BEDROCK_RERANKING_MODEL: "BEDROCK_RERANKING_MODEL";
};
export type RerankingConfigurationType =
  (typeof RerankingConfigurationType)[keyof typeof RerankingConfigurationType];
export declare const RerankDocumentType: {
  readonly JSON: "JSON";
  readonly TEXT: "TEXT";
};
export type RerankDocumentType =
  (typeof RerankDocumentType)[keyof typeof RerankDocumentType];
export declare const RerankSourceType: {
  readonly INLINE: "INLINE";
};
export type RerankSourceType =
  (typeof RerankSourceType)[keyof typeof RerankSourceType];
export declare const ExternalSourceType: {
  readonly BYTE_CONTENT: "BYTE_CONTENT";
  readonly S3: "S3";
};
export type ExternalSourceType =
  (typeof ExternalSourceType)[keyof typeof ExternalSourceType];
export declare const QueryTransformationType: {
  readonly QUERY_DECOMPOSITION: "QUERY_DECOMPOSITION";
};
export type QueryTransformationType =
  (typeof QueryTransformationType)[keyof typeof QueryTransformationType];
export declare const RetrieveAndGenerateType: {
  readonly EXTERNAL_SOURCES: "EXTERNAL_SOURCES";
  readonly KNOWLEDGE_BASE: "KNOWLEDGE_BASE";
};
export type RetrieveAndGenerateType =
  (typeof RetrieveAndGenerateType)[keyof typeof RetrieveAndGenerateType];
export declare const GuadrailAction: {
  readonly INTERVENED: "INTERVENED";
  readonly NONE: "NONE";
};
export type GuadrailAction =
  (typeof GuadrailAction)[keyof typeof GuadrailAction];
export declare const InputImageFormat: {
  readonly gif: "gif";
  readonly jpeg: "jpeg";
  readonly png: "png";
  readonly webp: "webp";
};
export type InputImageFormat =
  (typeof InputImageFormat)[keyof typeof InputImageFormat];
export declare const KnowledgeBaseQueryType: {
  readonly IMAGE: "IMAGE";
  readonly TEXT: "TEXT";
};
export type KnowledgeBaseQueryType =
  (typeof KnowledgeBaseQueryType)[keyof typeof KnowledgeBaseQueryType];
export declare const SessionStatus: {
  readonly ACTIVE: "ACTIVE";
  readonly ENDED: "ENDED";
  readonly EXPIRED: "EXPIRED";
};
export type SessionStatus = (typeof SessionStatus)[keyof typeof SessionStatus];
export declare const ImageFormat: {
  readonly GIF: "gif";
  readonly JPEG: "jpeg";
  readonly PNG: "png";
  readonly WEBP: "webp";
};
export type ImageFormat = (typeof ImageFormat)[keyof typeof ImageFormat];
