import type { Paginator } from "@smithy/types";
import { GetAgentMemoryCommandInput, GetAgentMemoryCommandOutput } from "../commands/GetAgentMemoryCommand";
import { BedrockAgentRuntimePaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateGetAgentMemory: (config: BedrockAgentRuntimePaginationConfiguration, input: GetAgentMemoryCommandInput, ...rest: any[]) => Paginator<GetAgentMemoryCommandOutput>;
