import type { Paginator } from "@smithy/types";
import { RerankCommandInput, RerankCommandOutput } from "../commands/RerankCommand";
import { BedrockAgentRuntimePaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateRerank: (config: BedrockAgentRuntimePaginationConfiguration, input: RerankCommandInput, ...rest: any[]) => Paginator<RerankCommandOutput>;
