import { TypeRegistry } from "@smithy/core/schema";
import type { StaticErrorSchema, StaticOperationSchema, StaticStructureSchema, StaticUnionSchema } from "@smithy/types";
export declare var BedrockAgentRuntimeServiceException$: StaticErrorSchema;
export declare var AccessDeniedException$: StaticErrorSchema;
export declare var BadGatewayException$: StaticErrorSchema;
export declare var ConflictException$: StaticErrorSchema;
export declare var DependencyFailedException$: StaticErrorSchema;
export declare var InternalServerException$: StaticErrorSchema;
export declare var ModelNotReadyException$: StaticErrorSchema;
export declare var ResourceNotFoundException$: StaticErrorSchema;
export declare var ServiceQuotaExceededException$: StaticErrorSchema;
export declare var ThrottlingException$: StaticErrorSchema;
export declare var ValidationException$: StaticErrorSchema;
/**
 * TypeRegistry instances containing modeled errors.
 * @internal
 *
 */
export declare const errorTypeRegistries: TypeRegistry[];
export declare var ActionGroupInvocationInput$: StaticStructureSchema;
export declare var ActionGroupInvocationOutput$: StaticStructureSchema;
export declare var AgentActionGroup$: StaticStructureSchema;
export declare var AgentCollaboratorInputPayload$: StaticStructureSchema;
export declare var AgentCollaboratorInvocationInput$: StaticStructureSchema;
export declare var AgentCollaboratorInvocationOutput$: StaticStructureSchema;
export declare var AgentCollaboratorOutputPayload$: StaticStructureSchema;
export declare var AnalyzePromptEvent$: StaticStructureSchema;
export declare var ApiInvocationInput$: StaticStructureSchema;
export declare var ApiParameter$: StaticStructureSchema;
export declare var ApiRequestBody$: StaticStructureSchema;
export declare var ApiResult$: StaticStructureSchema;
export declare var Attribution$: StaticStructureSchema;
export declare var AudioSegment$: StaticStructureSchema;
export declare var BedrockModelConfigurations$: StaticStructureSchema;
export declare var BedrockRerankingConfiguration$: StaticStructureSchema;
export declare var BedrockRerankingModelConfiguration$: StaticStructureSchema;
export declare var ByteContentDoc$: StaticStructureSchema;
export declare var ByteContentFile$: StaticStructureSchema;
export declare var Citation$: StaticStructureSchema;
export declare var CitationEvent$: StaticStructureSchema;
export declare var CodeInterpreterInvocationInput$: StaticStructureSchema;
export declare var CodeInterpreterInvocationOutput$: StaticStructureSchema;
export declare var Collaborator$: StaticStructureSchema;
export declare var CollaboratorConfiguration$: StaticStructureSchema;
export declare var ConditionResultEvent$: StaticStructureSchema;
export declare var ContentBody$: StaticStructureSchema;
export declare var ConversationHistory$: StaticStructureSchema;
export declare var CreateInvocationRequest$: StaticStructureSchema;
export declare var CreateInvocationResponse$: StaticStructureSchema;
export declare var CreateSessionRequest$: StaticStructureSchema;
export declare var CreateSessionResponse$: StaticStructureSchema;
export declare var CustomOrchestration$: StaticStructureSchema;
export declare var CustomOrchestrationTrace$: StaticStructureSchema;
export declare var CustomOrchestrationTraceEvent$: StaticStructureSchema;
export declare var DeleteAgentMemoryRequest$: StaticStructureSchema;
export declare var DeleteAgentMemoryResponse$: StaticStructureSchema;
export declare var DeleteSessionRequest$: StaticStructureSchema;
export declare var DeleteSessionResponse$: StaticStructureSchema;
export declare var EndSessionRequest$: StaticStructureSchema;
export declare var EndSessionResponse$: StaticStructureSchema;
export declare var ExternalSource$: StaticStructureSchema;
export declare var ExternalSourcesGenerationConfiguration$: StaticStructureSchema;
export declare var ExternalSourcesRetrieveAndGenerateConfiguration$: StaticStructureSchema;
export declare var FailureTrace$: StaticStructureSchema;
export declare var FieldForReranking$: StaticStructureSchema;
export declare var FilePart$: StaticStructureSchema;
export declare var FileSource$: StaticStructureSchema;
export declare var FilterAttribute$: StaticStructureSchema;
export declare var FinalResponse$: StaticStructureSchema;
export declare var FlowCompletionEvent$: StaticStructureSchema;
export declare var FlowExecutionError$: StaticStructureSchema;
export declare var FlowExecutionInputEvent$: StaticStructureSchema;
export declare var FlowExecutionOutputEvent$: StaticStructureSchema;
export declare var FlowExecutionSummary$: StaticStructureSchema;
export declare var FlowFailureEvent$: StaticStructureSchema;
export declare var FlowInput$: StaticStructureSchema;
export declare var FlowInputField$: StaticStructureSchema;
export declare var FlowMultiTurnInputRequestEvent$: StaticStructureSchema;
export declare var FlowOutputEvent$: StaticStructureSchema;
export declare var FlowOutputField$: StaticStructureSchema;
export declare var FlowTraceCondition$: StaticStructureSchema;
export declare var FlowTraceConditionNodeResultEvent$: StaticStructureSchema;
export declare var FlowTraceDependencyEvent$: StaticStructureSchema;
export declare var FlowTraceEvent$: StaticStructureSchema;
export declare var FlowTraceNodeActionEvent$: StaticStructureSchema;
export declare var FlowTraceNodeInputEvent$: StaticStructureSchema;
export declare var FlowTraceNodeInputExecutionChainItem$: StaticStructureSchema;
export declare var FlowTraceNodeInputField$: StaticStructureSchema;
export declare var FlowTraceNodeInputSource$: StaticStructureSchema;
export declare var FlowTraceNodeOutputEvent$: StaticStructureSchema;
export declare var FlowTraceNodeOutputField$: StaticStructureSchema;
export declare var FlowTraceNodeOutputNext$: StaticStructureSchema;
export declare var FunctionDefinition$: StaticStructureSchema;
export declare var FunctionInvocationInput$: StaticStructureSchema;
export declare var FunctionParameter$: StaticStructureSchema;
export declare var FunctionResult$: StaticStructureSchema;
export declare var GeneratedQuery$: StaticStructureSchema;
export declare var GeneratedResponsePart$: StaticStructureSchema;
export declare var GenerateQueryRequest$: StaticStructureSchema;
export declare var GenerateQueryResponse$: StaticStructureSchema;
export declare var GenerationConfiguration$: StaticStructureSchema;
export declare var GetAgentMemoryRequest$: StaticStructureSchema;
export declare var GetAgentMemoryResponse$: StaticStructureSchema;
export declare var GetExecutionFlowSnapshotRequest$: StaticStructureSchema;
export declare var GetExecutionFlowSnapshotResponse$: StaticStructureSchema;
export declare var GetFlowExecutionRequest$: StaticStructureSchema;
export declare var GetFlowExecutionResponse$: StaticStructureSchema;
export declare var GetInvocationStepRequest$: StaticStructureSchema;
export declare var GetInvocationStepResponse$: StaticStructureSchema;
export declare var GetSessionRequest$: StaticStructureSchema;
export declare var GetSessionResponse$: StaticStructureSchema;
export declare var GuardrailAssessment$: StaticStructureSchema;
export declare var GuardrailConfiguration$: StaticStructureSchema;
export declare var GuardrailConfigurationWithArn$: StaticStructureSchema;
export declare var GuardrailContentFilter$: StaticStructureSchema;
export declare var GuardrailContentPolicyAssessment$: StaticStructureSchema;
export declare var GuardrailCustomWord$: StaticStructureSchema;
export declare var GuardrailEvent$: StaticStructureSchema;
export declare var GuardrailManagedWord$: StaticStructureSchema;
export declare var GuardrailPiiEntityFilter$: StaticStructureSchema;
export declare var GuardrailRegexFilter$: StaticStructureSchema;
export declare var GuardrailSensitiveInformationPolicyAssessment$: StaticStructureSchema;
export declare var GuardrailTopic$: StaticStructureSchema;
export declare var GuardrailTopicPolicyAssessment$: StaticStructureSchema;
export declare var GuardrailTrace$: StaticStructureSchema;
export declare var GuardrailWordPolicyAssessment$: StaticStructureSchema;
export declare var ImageBlock$: StaticStructureSchema;
export declare var ImageInput$: StaticStructureSchema;
export declare var ImplicitFilterConfiguration$: StaticStructureSchema;
export declare var InferenceConfig$: StaticStructureSchema;
export declare var InferenceConfiguration$: StaticStructureSchema;
export declare var InlineAgentFilePart$: StaticStructureSchema;
export declare var InlineAgentPayloadPart$: StaticStructureSchema;
export declare var InlineAgentReturnControlPayload$: StaticStructureSchema;
export declare var InlineAgentTracePart$: StaticStructureSchema;
export declare var InlineBedrockModelConfigurations$: StaticStructureSchema;
export declare var InlineSessionState$: StaticStructureSchema;
export declare var InputFile$: StaticStructureSchema;
export declare var InputImage$: StaticStructureSchema;
export declare var InvocationInput$: StaticStructureSchema;
export declare var InvocationStep$: StaticStructureSchema;
export declare var InvocationStepSummary$: StaticStructureSchema;
export declare var InvocationSummary$: StaticStructureSchema;
export declare var InvokeAgentRequest$: StaticStructureSchema;
export declare var InvokeAgentResponse$: StaticStructureSchema;
export declare var InvokeFlowRequest$: StaticStructureSchema;
export declare var InvokeFlowResponse$: StaticStructureSchema;
export declare var InvokeInlineAgentRequest$: StaticStructureSchema;
export declare var InvokeInlineAgentResponse$: StaticStructureSchema;
export declare var KnowledgeBase$: StaticStructureSchema;
export declare var KnowledgeBaseConfiguration$: StaticStructureSchema;
export declare var KnowledgeBaseLookupInput$: StaticStructureSchema;
export declare var KnowledgeBaseLookupOutput$: StaticStructureSchema;
export declare var KnowledgeBaseQuery$: StaticStructureSchema;
export declare var KnowledgeBaseRetrievalConfiguration$: StaticStructureSchema;
export declare var KnowledgeBaseRetrievalResult$: StaticStructureSchema;
export declare var KnowledgeBaseRetrieveAndGenerateConfiguration$: StaticStructureSchema;
export declare var KnowledgeBaseVectorSearchConfiguration$: StaticStructureSchema;
export declare var ListFlowExecutionEventsRequest$: StaticStructureSchema;
export declare var ListFlowExecutionEventsResponse$: StaticStructureSchema;
export declare var ListFlowExecutionsRequest$: StaticStructureSchema;
export declare var ListFlowExecutionsResponse$: StaticStructureSchema;
export declare var ListInvocationsRequest$: StaticStructureSchema;
export declare var ListInvocationsResponse$: StaticStructureSchema;
export declare var ListInvocationStepsRequest$: StaticStructureSchema;
export declare var ListInvocationStepsResponse$: StaticStructureSchema;
export declare var ListSessionsRequest$: StaticStructureSchema;
export declare var ListSessionsResponse$: StaticStructureSchema;
export declare var ListTagsForResourceRequest$: StaticStructureSchema;
export declare var ListTagsForResourceResponse$: StaticStructureSchema;
export declare var MemorySessionSummary$: StaticStructureSchema;
export declare var Message$: StaticStructureSchema;
export declare var Metadata$: StaticStructureSchema;
export declare var MetadataAttributeSchema$: StaticStructureSchema;
export declare var MetadataConfigurationForReranking$: StaticStructureSchema;
export declare var ModelInvocationInput$: StaticStructureSchema;
export declare var ModelPerformanceConfiguration$: StaticStructureSchema;
export declare var NodeActionEvent$: StaticStructureSchema;
export declare var NodeDependencyEvent$: StaticStructureSchema;
export declare var NodeFailureEvent$: StaticStructureSchema;
export declare var NodeInputEvent$: StaticStructureSchema;
export declare var NodeInputExecutionChainItem$: StaticStructureSchema;
export declare var NodeInputField$: StaticStructureSchema;
export declare var NodeInputSource$: StaticStructureSchema;
export declare var NodeOutputEvent$: StaticStructureSchema;
export declare var NodeOutputField$: StaticStructureSchema;
export declare var NodeOutputNext$: StaticStructureSchema;
export declare var Observation$: StaticStructureSchema;
export declare var OptimizedPromptEvent$: StaticStructureSchema;
export declare var OptimizePromptRequest$: StaticStructureSchema;
export declare var OptimizePromptResponse$: StaticStructureSchema;
export declare var OrchestrationConfiguration$: StaticStructureSchema;
export declare var OrchestrationModelInvocationOutput$: StaticStructureSchema;
export declare var OutputFile$: StaticStructureSchema;
export declare var Parameter$: StaticStructureSchema;
export declare var ParameterDetail$: StaticStructureSchema;
export declare var PayloadPart$: StaticStructureSchema;
export declare var PerformanceConfiguration$: StaticStructureSchema;
export declare var PostProcessingModelInvocationOutput$: StaticStructureSchema;
export declare var PostProcessingParsedResponse$: StaticStructureSchema;
export declare var PreProcessingModelInvocationOutput$: StaticStructureSchema;
export declare var PreProcessingParsedResponse$: StaticStructureSchema;
export declare var PromptConfiguration$: StaticStructureSchema;
export declare var PromptCreationConfigurations$: StaticStructureSchema;
export declare var PromptOverrideConfiguration$: StaticStructureSchema;
export declare var PromptTemplate$: StaticStructureSchema;
export declare var PropertyParameters$: StaticStructureSchema;
export declare var PutInvocationStepRequest$: StaticStructureSchema;
export declare var PutInvocationStepResponse$: StaticStructureSchema;
export declare var QueryGenerationInput$: StaticStructureSchema;
export declare var QueryTransformationConfiguration$: StaticStructureSchema;
export declare var Rationale$: StaticStructureSchema;
export declare var RawResponse$: StaticStructureSchema;
export declare var ReasoningTextBlock$: StaticStructureSchema;
export declare var RepromptResponse$: StaticStructureSchema;
export declare var RequestBody$: StaticStructureSchema;
export declare var RerankDocument$: StaticStructureSchema;
export declare var RerankingConfiguration$: StaticStructureSchema;
export declare var RerankQuery$: StaticStructureSchema;
export declare var RerankRequest$: StaticStructureSchema;
export declare var RerankResponse$: StaticStructureSchema;
export declare var RerankResult$: StaticStructureSchema;
export declare var RerankSource$: StaticStructureSchema;
export declare var RerankTextDocument$: StaticStructureSchema;
export declare var RetrievalResultConfluenceLocation$: StaticStructureSchema;
export declare var RetrievalResultContent$: StaticStructureSchema;
export declare var RetrievalResultContentColumn$: StaticStructureSchema;
export declare var RetrievalResultCustomDocumentLocation$: StaticStructureSchema;
export declare var RetrievalResultKendraDocumentLocation$: StaticStructureSchema;
export declare var RetrievalResultLocation$: StaticStructureSchema;
export declare var RetrievalResultS3Location$: StaticStructureSchema;
export declare var RetrievalResultSalesforceLocation$: StaticStructureSchema;
export declare var RetrievalResultSharePointLocation$: StaticStructureSchema;
export declare var RetrievalResultSqlLocation$: StaticStructureSchema;
export declare var RetrievalResultWebLocation$: StaticStructureSchema;
export declare var RetrieveAndGenerateConfiguration$: StaticStructureSchema;
export declare var RetrieveAndGenerateInput$: StaticStructureSchema;
export declare var RetrieveAndGenerateOutput$: StaticStructureSchema;
export declare var RetrieveAndGenerateOutputEvent$: StaticStructureSchema;
export declare var RetrieveAndGenerateRequest$: StaticStructureSchema;
export declare var RetrieveAndGenerateResponse$: StaticStructureSchema;
export declare var RetrieveAndGenerateSessionConfiguration$: StaticStructureSchema;
export declare var RetrieveAndGenerateStreamRequest$: StaticStructureSchema;
export declare var RetrieveAndGenerateStreamResponse$: StaticStructureSchema;
export declare var RetrievedReference$: StaticStructureSchema;
export declare var RetrieveRequest$: StaticStructureSchema;
export declare var RetrieveResponse$: StaticStructureSchema;
export declare var ReturnControlPayload$: StaticStructureSchema;
export declare var ReturnControlResults$: StaticStructureSchema;
export declare var RoutingClassifierModelInvocationOutput$: StaticStructureSchema;
export declare var S3Identifier$: StaticStructureSchema;
export declare var S3Location$: StaticStructureSchema;
export declare var S3ObjectDoc$: StaticStructureSchema;
export declare var S3ObjectFile$: StaticStructureSchema;
export declare var SatisfiedCondition$: StaticStructureSchema;
export declare var SessionState$: StaticStructureSchema;
export declare var SessionSummary$: StaticStructureSchema;
export declare var Span$: StaticStructureSchema;
export declare var StartFlowExecutionRequest$: StaticStructureSchema;
export declare var StartFlowExecutionResponse$: StaticStructureSchema;
export declare var StopFlowExecutionRequest$: StaticStructureSchema;
export declare var StopFlowExecutionResponse$: StaticStructureSchema;
export declare var StreamingConfigurations$: StaticStructureSchema;
export declare var TagResourceRequest$: StaticStructureSchema;
export declare var TagResourceResponse$: StaticStructureSchema;
export declare var TextInferenceConfig$: StaticStructureSchema;
export declare var TextPrompt$: StaticStructureSchema;
export declare var TextResponsePart$: StaticStructureSchema;
export declare var TextToSqlConfiguration$: StaticStructureSchema;
export declare var TextToSqlKnowledgeBaseConfiguration$: StaticStructureSchema;
export declare var TracePart$: StaticStructureSchema;
export declare var TransformationConfiguration$: StaticStructureSchema;
export declare var UntagResourceRequest$: StaticStructureSchema;
export declare var UntagResourceResponse$: StaticStructureSchema;
export declare var UpdateSessionRequest$: StaticStructureSchema;
export declare var UpdateSessionResponse$: StaticStructureSchema;
export declare var Usage$: StaticStructureSchema;
export declare var VectorSearchBedrockRerankingConfiguration$: StaticStructureSchema;
export declare var VectorSearchBedrockRerankingModelConfiguration$: StaticStructureSchema;
export declare var VectorSearchRerankingConfiguration$: StaticStructureSchema;
export declare var VideoSegment$: StaticStructureSchema;
export declare var ActionGroupExecutor$: StaticUnionSchema;
export declare var APISchema$: StaticUnionSchema;
export declare var BedrockSessionContentBlock$: StaticUnionSchema;
export declare var Caller$: StaticUnionSchema;
export declare var ContentBlock$: StaticUnionSchema;
export declare var FlowExecutionContent$: StaticUnionSchema;
export declare var FlowExecutionEvent$: StaticUnionSchema;
export declare var FlowInputContent$: StaticUnionSchema;
export declare var FlowMultiTurnInputContent$: StaticUnionSchema;
export declare var FlowOutputContent$: StaticUnionSchema;
export declare var FlowResponseStream$: StaticUnionSchema;
export declare var FlowTrace$: StaticUnionSchema;
export declare var FlowTraceNodeInputContent$: StaticUnionSchema;
export declare var FlowTraceNodeOutputContent$: StaticUnionSchema;
export declare var FunctionSchema$: StaticUnionSchema;
export declare var ImageInputSource$: StaticUnionSchema;
export declare var ImageSource$: StaticUnionSchema;
export declare var InlineAgentResponseStream$: StaticUnionSchema;
export declare var InputPrompt$: StaticUnionSchema;
export declare var InvocationInputMember$: StaticUnionSchema;
export declare var InvocationResultMember$: StaticUnionSchema;
export declare var InvocationStepPayload$: StaticUnionSchema;
export declare var Memory$: StaticUnionSchema;
export declare var NodeExecutionContent$: StaticUnionSchema;
export declare var NodeTraceElements$: StaticUnionSchema;
export declare var OptimizedPrompt$: StaticUnionSchema;
export declare var OptimizedPromptStream$: StaticUnionSchema;
export declare var OrchestrationExecutor$: StaticUnionSchema;
export declare var OrchestrationTrace$: StaticUnionSchema;
export declare var PostProcessingTrace$: StaticUnionSchema;
export declare var PreProcessingTrace$: StaticUnionSchema;
export declare var ReasoningContentBlock$: StaticUnionSchema;
export declare var RerankingMetadataSelectiveModeConfiguration$: StaticUnionSchema;
export declare var ResponseStream$: StaticUnionSchema;
export declare var RetrievalFilter$: StaticUnionSchema;
export declare var RetrieveAndGenerateStreamResponseOutput$: StaticUnionSchema;
export declare var RoutingClassifierTrace$: StaticUnionSchema;
export declare var Trace$: StaticUnionSchema;
export declare var TraceElements$: StaticUnionSchema;
export declare var CreateInvocation$: StaticOperationSchema;
export declare var CreateSession$: StaticOperationSchema;
export declare var DeleteAgentMemory$: StaticOperationSchema;
export declare var DeleteSession$: StaticOperationSchema;
export declare var EndSession$: StaticOperationSchema;
export declare var GenerateQuery$: StaticOperationSchema;
export declare var GetAgentMemory$: StaticOperationSchema;
export declare var GetExecutionFlowSnapshot$: StaticOperationSchema;
export declare var GetFlowExecution$: StaticOperationSchema;
export declare var GetInvocationStep$: StaticOperationSchema;
export declare var GetSession$: StaticOperationSchema;
export declare var InvokeAgent$: StaticOperationSchema;
export declare var InvokeFlow$: StaticOperationSchema;
export declare var InvokeInlineAgent$: StaticOperationSchema;
export declare var ListFlowExecutionEvents$: StaticOperationSchema;
export declare var ListFlowExecutions$: StaticOperationSchema;
export declare var ListInvocations$: StaticOperationSchema;
export declare var ListInvocationSteps$: StaticOperationSchema;
export declare var ListSessions$: StaticOperationSchema;
export declare var ListTagsForResource$: StaticOperationSchema;
export declare var OptimizePrompt$: StaticOperationSchema;
export declare var PutInvocationStep$: StaticOperationSchema;
export declare var Rerank$: StaticOperationSchema;
export declare var Retrieve$: StaticOperationSchema;
export declare var RetrieveAndGenerate$: StaticOperationSchema;
export declare var RetrieveAndGenerateStream$: StaticOperationSchema;
export declare var StartFlowExecution$: StaticOperationSchema;
export declare var StopFlowExecution$: StaticOperationSchema;
export declare var TagResource$: StaticOperationSchema;
export declare var UntagResource$: StaticOperationSchema;
export declare var UpdateSession$: StaticOperationSchema;
