import { createPaginator } from "@smithy/core";
import { BedrockAgentRuntimeClient } from "../BedrockAgentRuntimeClient";
import { RerankCommand } from "../commands/RerankCommand";
export const paginateRerank = createPaginator(BedrockAgentRuntimeClient, RerankCommand, "nextToken", "nextToken", "");
