import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  BedrockAgentRuntimeClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../BedrockAgentRuntimeClient";
import { GetSessionRequest, GetSessionResponse } from "../models/models_0";
export { __MetadataBearer };
export { $Command };
export interface GetSessionCommandInput extends GetSessionRequest {}
export interface GetSessionCommandOutput
  extends GetSessionResponse,
    __MetadataBearer {}
declare const GetSessionCommand_base: {
  new (
    input: GetSessionCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    GetSessionCommandInput,
    GetSessionCommandOutput,
    BedrockAgentRuntimeClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: GetSessionCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    GetSessionCommandInput,
    GetSessionCommandOutput,
    BedrockAgentRuntimeClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class GetSessionCommand extends GetSessionCommand_base {
  protected static __types: {
    api: {
      input: GetSessionRequest;
      output: GetSessionResponse;
    };
    sdk: {
      input: GetSessionCommandInput;
      output: GetSessionCommandOutput;
    };
  };
}
