/**
 * @public
 * @enum
 */
export declare const CustomControlMethod: {
    readonly RETURN_CONTROL: "RETURN_CONTROL";
};
/**
 * @public
 */
export type CustomControlMethod = (typeof CustomControlMethod)[keyof typeof CustomControlMethod];
/**
 * @public
 * @enum
 */
export declare const ExecutionType: {
    readonly LAMBDA: "LAMBDA";
    readonly RETURN_CONTROL: "RETURN_CONTROL";
};
/**
 * @public
 */
export type ExecutionType = (typeof ExecutionType)[keyof typeof ExecutionType];
/**
 * @public
 * @enum
 */
export declare const ActionGroupSignature: {
    readonly AMAZON_CODEINTERPRETER: "AMAZON.CodeInterpreter";
    readonly AMAZON_USERINPUT: "AMAZON.UserInput";
    readonly ANTHROPIC_BASH: "ANTHROPIC.Bash";
    readonly ANTHROPIC_COMPUTER: "ANTHROPIC.Computer";
    readonly ANTHROPIC_TEXTEDITOR: "ANTHROPIC.TextEditor";
};
/**
 * @public
 */
export type ActionGroupSignature = (typeof ActionGroupSignature)[keyof typeof ActionGroupSignature];
/**
 * @public
 * @enum
 */
export declare const ActionInvocationType: {
    readonly RESULT: "RESULT";
    readonly USER_CONFIRMATION: "USER_CONFIRMATION";
    readonly USER_CONFIRMATION_AND_RESULT: "USER_CONFIRMATION_AND_RESULT";
};
/**
 * @public
 */
export type ActionInvocationType = (typeof ActionInvocationType)[keyof typeof ActionInvocationType];
/**
 * @public
 * @enum
 */
export declare const ParameterType: {
    readonly ARRAY: "array";
    readonly BOOLEAN: "boolean";
    readonly INTEGER: "integer";
    readonly NUMBER: "number";
    readonly STRING: "string";
};
/**
 * @public
 */
export type ParameterType = (typeof ParameterType)[keyof typeof ParameterType];
/**
 * @public
 * @enum
 */
export declare const RequireConfirmation: {
    readonly DISABLED: "DISABLED";
    readonly ENABLED: "ENABLED";
};
/**
 * @public
 */
export type RequireConfirmation = (typeof RequireConfirmation)[keyof typeof RequireConfirmation];
/**
 * @public
 * @enum
 */
export declare const AgentCollaboration: {
    readonly DISABLED: "DISABLED";
    readonly SUPERVISOR: "SUPERVISOR";
    readonly SUPERVISOR_ROUTER: "SUPERVISOR_ROUTER";
};
/**
 * @public
 */
export type AgentCollaboration = (typeof AgentCollaboration)[keyof typeof AgentCollaboration];
/**
 * @public
 * @enum
 */
export declare const ConfirmationState: {
    readonly CONFIRM: "CONFIRM";
    readonly DENY: "DENY";
};
/**
 * @public
 */
export type ConfirmationState = (typeof ConfirmationState)[keyof typeof ConfirmationState];
/**
 * @public
 * @enum
 */
export declare const ImageInputFormat: {
    readonly GIF: "gif";
    readonly JPEG: "jpeg";
    readonly PNG: "png";
    readonly WEBP: "webp";
};
/**
 * @public
 */
export type ImageInputFormat = (typeof ImageInputFormat)[keyof typeof ImageInputFormat];
/**
 * @public
 * @enum
 */
export declare const ResponseState: {
    readonly FAILURE: "FAILURE";
    readonly REPROMPT: "REPROMPT";
};
/**
 * @public
 */
export type ResponseState = (typeof ResponseState)[keyof typeof ResponseState];
/**
 * @public
 * @enum
 */
export declare const PayloadType: {
    readonly RETURN_CONTROL: "RETURN_CONTROL";
    readonly TEXT: "TEXT";
};
/**
 * @public
 */
export type PayloadType = (typeof PayloadType)[keyof typeof PayloadType];
/**
 * @public
 * @enum
 */
export declare const GuardrailAction: {
    readonly INTERVENED: "INTERVENED";
    readonly NONE: "NONE";
};
/**
 * @public
 */
export type GuardrailAction = (typeof GuardrailAction)[keyof typeof GuardrailAction];
/**
 * @public
 * @enum
 */
export declare const GuardrailContentPolicyAction: {
    readonly BLOCKED: "BLOCKED";
};
/**
 * @public
 */
export type GuardrailContentPolicyAction = (typeof GuardrailContentPolicyAction)[keyof typeof GuardrailContentPolicyAction];
/**
 * @public
 * @enum
 */
export declare const GuardrailContentFilterConfidence: {
    readonly HIGH: "HIGH";
    readonly LOW: "LOW";
    readonly MEDIUM: "MEDIUM";
    readonly NONE: "NONE";
};
/**
 * @public
 */
export type GuardrailContentFilterConfidence = (typeof GuardrailContentFilterConfidence)[keyof typeof GuardrailContentFilterConfidence];
/**
 * @public
 * @enum
 */
export declare const GuardrailContentFilterType: {
    readonly HATE: "HATE";
    readonly INSULTS: "INSULTS";
    readonly MISCONDUCT: "MISCONDUCT";
    readonly PROMPT_ATTACK: "PROMPT_ATTACK";
    readonly SEXUAL: "SEXUAL";
    readonly VIOLENCE: "VIOLENCE";
};
/**
 * @public
 */
export type GuardrailContentFilterType = (typeof GuardrailContentFilterType)[keyof typeof GuardrailContentFilterType];
/**
 * @public
 * @enum
 */
export declare const GuardrailSensitiveInformationPolicyAction: {
    readonly ANONYMIZED: "ANONYMIZED";
    readonly BLOCKED: "BLOCKED";
};
/**
 * @public
 */
export type GuardrailSensitiveInformationPolicyAction = (typeof GuardrailSensitiveInformationPolicyAction)[keyof typeof GuardrailSensitiveInformationPolicyAction];
/**
 * @public
 * @enum
 */
export declare const GuardrailPiiEntityType: {
    readonly ADDRESS: "ADDRESS";
    readonly AGE: "AGE";
    readonly AWS_ACCESS_KEY: "AWS_ACCESS_KEY";
    readonly AWS_SECRET_KEY: "AWS_SECRET_KEY";
    readonly CA_HEALTH_NUMBER: "CA_HEALTH_NUMBER";
    readonly CA_SOCIAL_INSURANCE_NUMBER: "CA_SOCIAL_INSURANCE_NUMBER";
    readonly CREDIT_DEBIT_CARD_CVV: "CREDIT_DEBIT_CARD_CVV";
    readonly CREDIT_DEBIT_CARD_EXPIRY: "CREDIT_DEBIT_CARD_EXPIRY";
    readonly CREDIT_DEBIT_CARD_NUMBER: "CREDIT_DEBIT_CARD_NUMBER";
    readonly DRIVER_ID: "DRIVER_ID";
    readonly EMAIL: "EMAIL";
    readonly INTERNATIONAL_BANK_ACCOUNT_NUMBER: "INTERNATIONAL_BANK_ACCOUNT_NUMBER";
    readonly IP_ADDRESS: "IP_ADDRESS";
    readonly LICENSE_PLATE: "LICENSE_PLATE";
    readonly MAC_ADDRESS: "MAC_ADDRESS";
    readonly NAME: "NAME";
    readonly PASSWORD: "PASSWORD";
    readonly PHONE: "PHONE";
    readonly PIN: "PIN";
    readonly SWIFT_CODE: "SWIFT_CODE";
    readonly UK_NATIONAL_HEALTH_SERVICE_NUMBER: "UK_NATIONAL_HEALTH_SERVICE_NUMBER";
    readonly UK_NATIONAL_INSURANCE_NUMBER: "UK_NATIONAL_INSURANCE_NUMBER";
    readonly UK_UNIQUE_TAXPAYER_REFERENCE_NUMBER: "UK_UNIQUE_TAXPAYER_REFERENCE_NUMBER";
    readonly URL: "URL";
    readonly USERNAME: "USERNAME";
    readonly US_BANK_ACCOUNT_NUMBER: "US_BANK_ACCOUNT_NUMBER";
    readonly US_BANK_ROUTING_NUMBER: "US_BANK_ROUTING_NUMBER";
    readonly US_INDIVIDUAL_TAX_IDENTIFICATION_NUMBER: "US_INDIVIDUAL_TAX_IDENTIFICATION_NUMBER";
    readonly US_PASSPORT_NUMBER: "US_PASSPORT_NUMBER";
    readonly US_SOCIAL_SECURITY_NUMBER: "US_SOCIAL_SECURITY_NUMBER";
    readonly VEHICLE_IDENTIFICATION_NUMBER: "VEHICLE_IDENTIFICATION_NUMBER";
};
/**
 * @public
 */
export type GuardrailPiiEntityType = (typeof GuardrailPiiEntityType)[keyof typeof GuardrailPiiEntityType];
/**
 * @public
 * @enum
 */
export declare const GuardrailTopicPolicyAction: {
    readonly BLOCKED: "BLOCKED";
};
/**
 * @public
 */
export type GuardrailTopicPolicyAction = (typeof GuardrailTopicPolicyAction)[keyof typeof GuardrailTopicPolicyAction];
/**
 * @public
 * @enum
 */
export declare const GuardrailTopicType: {
    readonly DENY: "DENY";
};
/**
 * @public
 */
export type GuardrailTopicType = (typeof GuardrailTopicType)[keyof typeof GuardrailTopicType];
/**
 * @public
 * @enum
 */
export declare const GuardrailWordPolicyAction: {
    readonly BLOCKED: "BLOCKED";
};
/**
 * @public
 */
export type GuardrailWordPolicyAction = (typeof GuardrailWordPolicyAction)[keyof typeof GuardrailWordPolicyAction];
/**
 * @public
 * @enum
 */
export declare const GuardrailManagedWordType: {
    readonly PROFANITY: "PROFANITY";
};
/**
 * @public
 */
export type GuardrailManagedWordType = (typeof GuardrailManagedWordType)[keyof typeof GuardrailManagedWordType];
/**
 * @public
 * @enum
 */
export declare const InvocationType: {
    readonly ACTION_GROUP: "ACTION_GROUP";
    readonly ACTION_GROUP_CODE_INTERPRETER: "ACTION_GROUP_CODE_INTERPRETER";
    readonly AGENT_COLLABORATOR: "AGENT_COLLABORATOR";
    readonly FINISH: "FINISH";
    readonly KNOWLEDGE_BASE: "KNOWLEDGE_BASE";
};
/**
 * @public
 */
export type InvocationType = (typeof InvocationType)[keyof typeof InvocationType];
/**
 * @public
 * @enum
 */
export declare const CreationMode: {
    readonly DEFAULT: "DEFAULT";
    readonly OVERRIDDEN: "OVERRIDDEN";
};
/**
 * @public
 */
export type CreationMode = (typeof CreationMode)[keyof typeof CreationMode];
/**
 * @public
 * @enum
 */
export declare const PromptType: {
    readonly KNOWLEDGE_BASE_RESPONSE_GENERATION: "KNOWLEDGE_BASE_RESPONSE_GENERATION";
    readonly ORCHESTRATION: "ORCHESTRATION";
    readonly POST_PROCESSING: "POST_PROCESSING";
    readonly PRE_PROCESSING: "PRE_PROCESSING";
    readonly ROUTING_CLASSIFIER: "ROUTING_CLASSIFIER";
};
/**
 * @public
 */
export type PromptType = (typeof PromptType)[keyof typeof PromptType];
/**
 * @public
 * @enum
 */
export declare const RetrievalResultContentColumnType: {
    readonly BLOB: "BLOB";
    readonly BOOLEAN: "BOOLEAN";
    readonly DOUBLE: "DOUBLE";
    readonly LONG: "LONG";
    readonly NULL: "NULL";
    readonly STRING: "STRING";
};
/**
 * @public
 */
export type RetrievalResultContentColumnType = (typeof RetrievalResultContentColumnType)[keyof typeof RetrievalResultContentColumnType];
/**
 * @public
 * @enum
 */
export declare const RetrievalResultContentType: {
    readonly AUDIO: "AUDIO";
    readonly IMAGE: "IMAGE";
    readonly ROW: "ROW";
    readonly TEXT: "TEXT";
    readonly VIDEO: "VIDEO";
};
/**
 * @public
 */
export type RetrievalResultContentType = (typeof RetrievalResultContentType)[keyof typeof RetrievalResultContentType];
/**
 * @public
 * @enum
 */
export declare const RetrievalResultLocationType: {
    readonly CONFLUENCE: "CONFLUENCE";
    readonly CUSTOM: "CUSTOM";
    readonly KENDRA: "KENDRA";
    readonly S3: "S3";
    readonly SALESFORCE: "SALESFORCE";
    readonly SHAREPOINT: "SHAREPOINT";
    readonly SQL: "SQL";
    readonly WEB: "WEB";
};
/**
 * @public
 */
export type RetrievalResultLocationType = (typeof RetrievalResultLocationType)[keyof typeof RetrievalResultLocationType];
/**
 * @public
 * @enum
 */
export declare const Source: {
    readonly ACTION_GROUP: "ACTION_GROUP";
    readonly KNOWLEDGE_BASE: "KNOWLEDGE_BASE";
    readonly PARSER: "PARSER";
};
/**
 * @public
 */
export type Source = (typeof Source)[keyof typeof Source];
/**
 * @public
 * @enum
 */
export declare const Type: {
    readonly ACTION_GROUP: "ACTION_GROUP";
    readonly AGENT_COLLABORATOR: "AGENT_COLLABORATOR";
    readonly ASK_USER: "ASK_USER";
    readonly FINISH: "FINISH";
    readonly KNOWLEDGE_BASE: "KNOWLEDGE_BASE";
    readonly REPROMPT: "REPROMPT";
};
/**
 * @public
 */
export type Type = (typeof Type)[keyof typeof Type];
/**
 * @public
 * @enum
 */
export declare const FlowExecutionErrorType: {
    readonly TIMED_OUT: "ExecutionTimedOut";
};
/**
 * @public
 */
export type FlowExecutionErrorType = (typeof FlowExecutionErrorType)[keyof typeof FlowExecutionErrorType];
/**
 * @public
 * @enum
 */
export declare const FlowExecutionStatus: {
    readonly ABORTED: "Aborted";
    readonly FAILED: "Failed";
    readonly RUNNING: "Running";
    readonly SUCCEEDED: "Succeeded";
    readonly TIMED_OUT: "TimedOut";
};
/**
 * @public
 */
export type FlowExecutionStatus = (typeof FlowExecutionStatus)[keyof typeof FlowExecutionStatus];
/**
 * @public
 * @enum
 */
export declare const FlowExecutionEventType: {
    readonly FLOW: "Flow";
    readonly NODE: "Node";
};
/**
 * @public
 */
export type FlowExecutionEventType = (typeof FlowExecutionEventType)[keyof typeof FlowExecutionEventType];
/**
 * @public
 * @enum
 */
export declare const FlowErrorCode: {
    readonly INTERNAL_SERVER: "INTERNAL_SERVER";
    readonly NODE_EXECUTION_FAILED: "NODE_EXECUTION_FAILED";
    readonly VALIDATION: "VALIDATION";
};
/**
 * @public
 */
export type FlowErrorCode = (typeof FlowErrorCode)[keyof typeof FlowErrorCode];
/**
 * @public
 * @enum
 */
export declare const NodeErrorCode: {
    readonly BAD_GATEWAY: "BAD_GATEWAY";
    readonly DEPENDENCY_FAILED: "DEPENDENCY_FAILED";
    readonly INTERNAL_SERVER: "INTERNAL_SERVER";
    readonly VALIDATION: "VALIDATION";
};
/**
 * @public
 */
export type NodeErrorCode = (typeof NodeErrorCode)[keyof typeof NodeErrorCode];
/**
 * @public
 * @enum
 */
export declare const FlowNodeInputCategory: {
    readonly EXIT_LOOP: "ExitLoop";
    readonly LOOP_CONDITION: "LoopCondition";
    readonly RETURN_VALUE_TO_LOOP_START: "ReturnValueToLoopStart";
};
/**
 * @public
 */
export type FlowNodeInputCategory = (typeof FlowNodeInputCategory)[keyof typeof FlowNodeInputCategory];
/**
 * @public
 * @enum
 */
export declare const FlowControlNodeType: {
    readonly ITERATOR: "Iterator";
    readonly LOOP: "Loop";
};
/**
 * @public
 */
export type FlowControlNodeType = (typeof FlowControlNodeType)[keyof typeof FlowControlNodeType];
/**
 * @public
 * @enum
 */
export declare const FlowNodeIODataType: {
    readonly ARRAY: "Array";
    readonly BOOLEAN: "Boolean";
    readonly NUMBER: "Number";
    readonly OBJECT: "Object";
    readonly STRING: "String";
};
/**
 * @public
 */
export type FlowNodeIODataType = (typeof FlowNodeIODataType)[keyof typeof FlowNodeIODataType];
/**
 * @public
 * @enum
 */
export declare const PerformanceConfigLatency: {
    readonly OPTIMIZED: "optimized";
    readonly STANDARD: "standard";
};
/**
 * @public
 */
export type PerformanceConfigLatency = (typeof PerformanceConfigLatency)[keyof typeof PerformanceConfigLatency];
/**
 * @public
 * @enum
 */
export declare const FlowCompletionReason: {
    readonly INPUT_REQUIRED: "INPUT_REQUIRED";
    readonly SUCCESS: "SUCCESS";
};
/**
 * @public
 */
export type FlowCompletionReason = (typeof FlowCompletionReason)[keyof typeof FlowCompletionReason];
/**
 * @public
 * @enum
 */
export declare const NodeType: {
    readonly CONDITION_NODE: "ConditionNode";
    readonly FLOW_INPUT_NODE: "FlowInputNode";
    readonly FLOW_OUTPUT_NODE: "FlowOutputNode";
    readonly KNOWLEDGE_BASE_NODE: "KnowledgeBaseNode";
    readonly LAMBDA_FUNCTION_NODE: "LambdaFunctionNode";
    readonly LEX_NODE: "LexNode";
    readonly PROMPT_NODE: "PromptNode";
};
/**
 * @public
 */
export type NodeType = (typeof NodeType)[keyof typeof NodeType];
/**
 * @public
 * @enum
 */
export declare const InputQueryType: {
    readonly TEXT: "TEXT";
};
/**
 * @public
 */
export type InputQueryType = (typeof InputQueryType)[keyof typeof InputQueryType];
/**
 * @public
 * @enum
 */
export declare const QueryTransformationMode: {
    readonly TEXT_TO_SQL: "TEXT_TO_SQL";
};
/**
 * @public
 */
export type QueryTransformationMode = (typeof QueryTransformationMode)[keyof typeof QueryTransformationMode];
/**
 * @public
 * @enum
 */
export declare const TextToSqlConfigurationType: {
    readonly KNOWLEDGE_BASE: "KNOWLEDGE_BASE";
};
/**
 * @public
 */
export type TextToSqlConfigurationType = (typeof TextToSqlConfigurationType)[keyof typeof TextToSqlConfigurationType];
/**
 * @public
 * @enum
 */
export declare const GeneratedQueryType: {
    readonly REDSHIFT_SQL: "REDSHIFT_SQL";
};
/**
 * @public
 */
export type GeneratedQueryType = (typeof GeneratedQueryType)[keyof typeof GeneratedQueryType];
/**
 * @public
 * @enum
 */
export declare const ConversationRole: {
    readonly ASSISTANT: "assistant";
    readonly USER: "user";
};
/**
 * @public
 */
export type ConversationRole = (typeof ConversationRole)[keyof typeof ConversationRole];
/**
 * @public
 * @enum
 */
export declare const FileSourceType: {
    readonly BYTE_CONTENT: "BYTE_CONTENT";
    readonly S3: "S3";
};
/**
 * @public
 */
export type FileSourceType = (typeof FileSourceType)[keyof typeof FileSourceType];
/**
 * @public
 * @enum
 */
export declare const FileUseCase: {
    readonly CHAT: "CHAT";
    readonly CODE_INTERPRETER: "CODE_INTERPRETER";
};
/**
 * @public
 */
export type FileUseCase = (typeof FileUseCase)[keyof typeof FileUseCase];
/**
 * @public
 * @enum
 */
export declare const AttributeType: {
    readonly BOOLEAN: "BOOLEAN";
    readonly NUMBER: "NUMBER";
    readonly STRING: "STRING";
    readonly STRING_LIST: "STRING_LIST";
};
/**
 * @public
 */
export type AttributeType = (typeof AttributeType)[keyof typeof AttributeType];
/**
 * @public
 * @enum
 */
export declare const SearchType: {
    readonly HYBRID: "HYBRID";
    readonly SEMANTIC: "SEMANTIC";
};
/**
 * @public
 */
export type SearchType = (typeof SearchType)[keyof typeof SearchType];
/**
 * @public
 * @enum
 */
export declare const RerankingMetadataSelectionMode: {
    readonly ALL: "ALL";
    readonly SELECTIVE: "SELECTIVE";
};
/**
 * @public
 */
export type RerankingMetadataSelectionMode = (typeof RerankingMetadataSelectionMode)[keyof typeof RerankingMetadataSelectionMode];
/**
 * @public
 * @enum
 */
export declare const VectorSearchRerankingConfigurationType: {
    readonly BEDROCK_RERANKING_MODEL: "BEDROCK_RERANKING_MODEL";
};
/**
 * @public
 */
export type VectorSearchRerankingConfigurationType = (typeof VectorSearchRerankingConfigurationType)[keyof typeof VectorSearchRerankingConfigurationType];
/**
 * @public
 * @enum
 */
export declare const RelayConversationHistory: {
    readonly DISABLED: "DISABLED";
    readonly TO_COLLABORATOR: "TO_COLLABORATOR";
};
/**
 * @public
 */
export type RelayConversationHistory = (typeof RelayConversationHistory)[keyof typeof RelayConversationHistory];
/**
 * @public
 * @enum
 */
export declare const PromptState: {
    readonly DISABLED: "DISABLED";
    readonly ENABLED: "ENABLED";
};
/**
 * @public
 */
export type PromptState = (typeof PromptState)[keyof typeof PromptState];
/**
 * @public
 * @enum
 */
export declare const OrchestrationType: {
    readonly CUSTOM_ORCHESTRATION: "CUSTOM_ORCHESTRATION";
    readonly DEFAULT: "DEFAULT";
};
/**
 * @public
 */
export type OrchestrationType = (typeof OrchestrationType)[keyof typeof OrchestrationType];
/**
 * @public
 * @enum
 */
export declare const MemoryType: {
    readonly SESSION_SUMMARY: "SESSION_SUMMARY";
};
/**
 * @public
 */
export type MemoryType = (typeof MemoryType)[keyof typeof MemoryType];
/**
 * @public
 * @enum
 */
export declare const RerankQueryContentType: {
    readonly TEXT: "TEXT";
};
/**
 * @public
 */
export type RerankQueryContentType = (typeof RerankQueryContentType)[keyof typeof RerankQueryContentType];
/**
 * @public
 * @enum
 */
export declare const RerankingConfigurationType: {
    readonly BEDROCK_RERANKING_MODEL: "BEDROCK_RERANKING_MODEL";
};
/**
 * @public
 */
export type RerankingConfigurationType = (typeof RerankingConfigurationType)[keyof typeof RerankingConfigurationType];
/**
 * @public
 * @enum
 */
export declare const RerankDocumentType: {
    readonly JSON: "JSON";
    readonly TEXT: "TEXT";
};
/**
 * @public
 */
export type RerankDocumentType = (typeof RerankDocumentType)[keyof typeof RerankDocumentType];
/**
 * @public
 * @enum
 */
export declare const RerankSourceType: {
    readonly INLINE: "INLINE";
};
/**
 * @public
 */
export type RerankSourceType = (typeof RerankSourceType)[keyof typeof RerankSourceType];
/**
 * @public
 * @enum
 */
export declare const ExternalSourceType: {
    readonly BYTE_CONTENT: "BYTE_CONTENT";
    readonly S3: "S3";
};
/**
 * @public
 */
export type ExternalSourceType = (typeof ExternalSourceType)[keyof typeof ExternalSourceType];
/**
 * @public
 * @enum
 */
export declare const QueryTransformationType: {
    readonly QUERY_DECOMPOSITION: "QUERY_DECOMPOSITION";
};
/**
 * @public
 */
export type QueryTransformationType = (typeof QueryTransformationType)[keyof typeof QueryTransformationType];
/**
 * @public
 * @enum
 */
export declare const RetrieveAndGenerateType: {
    readonly EXTERNAL_SOURCES: "EXTERNAL_SOURCES";
    readonly KNOWLEDGE_BASE: "KNOWLEDGE_BASE";
};
/**
 * @public
 */
export type RetrieveAndGenerateType = (typeof RetrieveAndGenerateType)[keyof typeof RetrieveAndGenerateType];
/**
 * @public
 * @enum
 */
export declare const GuadrailAction: {
    readonly INTERVENED: "INTERVENED";
    readonly NONE: "NONE";
};
/**
 * @public
 */
export type GuadrailAction = (typeof GuadrailAction)[keyof typeof GuadrailAction];
/**
 * @public
 * @enum
 */
export declare const InputImageFormat: {
    readonly gif: "gif";
    readonly jpeg: "jpeg";
    readonly png: "png";
    readonly webp: "webp";
};
/**
 * @public
 */
export type InputImageFormat = (typeof InputImageFormat)[keyof typeof InputImageFormat];
/**
 * @public
 * @enum
 */
export declare const KnowledgeBaseQueryType: {
    readonly IMAGE: "IMAGE";
    readonly TEXT: "TEXT";
};
/**
 * @public
 */
export type KnowledgeBaseQueryType = (typeof KnowledgeBaseQueryType)[keyof typeof KnowledgeBaseQueryType];
/**
 * @public
 * @enum
 */
export declare const SessionStatus: {
    readonly ACTIVE: "ACTIVE";
    readonly ENDED: "ENDED";
    readonly EXPIRED: "EXPIRED";
};
/**
 * @public
 */
export type SessionStatus = (typeof SessionStatus)[keyof typeof SessionStatus];
/**
 * @public
 * @enum
 */
export declare const ImageFormat: {
    readonly GIF: "gif";
    readonly JPEG: "jpeg";
    readonly PNG: "png";
    readonly WEBP: "webp";
};
/**
 * @public
 */
export type ImageFormat = (typeof ImageFormat)[keyof typeof ImageFormat];
