import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  BedrockAgentRuntimeClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../BedrockAgentRuntimeClient";
import {
  DeleteSessionRequest,
  DeleteSessionResponse,
} from "../models/models_0";
export { __MetadataBearer };
export { $Command };
export interface DeleteSessionCommandInput extends DeleteSessionRequest {}
export interface DeleteSessionCommandOutput
  extends DeleteSessionResponse,
    __MetadataBearer {}
declare const DeleteSessionCommand_base: {
  new (
    input: DeleteSessionCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    DeleteSessionCommandInput,
    DeleteSessionCommandOutput,
    BedrockAgentRuntimeClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: DeleteSessionCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    DeleteSessionCommandInput,
    DeleteSessionCommandOutput,
    BedrockAgentRuntimeClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class DeleteSessionCommand extends DeleteSessionCommand_base {
  protected static __types: {
    api: {
      input: DeleteSessionRequest;
      output: {};
    };
    sdk: {
      input: DeleteSessionCommandInput;
      output: DeleteSessionCommandOutput;
    };
  };
}
