import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  BedrockAgentRuntimeClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../BedrockAgentRuntimeClient";
import { InvokeInlineAgentResponse } from "../models/models_0";
import { InvokeInlineAgentRequest } from "../models/models_1";
export { __MetadataBearer };
export { $Command };
export interface InvokeInlineAgentCommandInput
  extends InvokeInlineAgentRequest {}
export interface InvokeInlineAgentCommandOutput
  extends InvokeInlineAgentResponse,
    __MetadataBearer {}
declare const InvokeInlineAgentCommand_base: {
  new (
    input: InvokeInlineAgentCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    InvokeInlineAgentCommandInput,
    InvokeInlineAgentCommandOutput,
    BedrockAgentRuntimeClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: InvokeInlineAgentCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    InvokeInlineAgentCommandInput,
    InvokeInlineAgentCommandOutput,
    BedrockAgentRuntimeClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class InvokeInlineAgentCommand extends InvokeInlineAgentCommand_base {
  protected static __types: {
    api: {
      input: InvokeInlineAgentRequest;
      output: InvokeInlineAgentResponse;
    };
    sdk: {
      input: InvokeInlineAgentCommandInput;
      output: InvokeInlineAgentCommandOutput;
    };
  };
}
