import type { Paginator } from "@smithy/types";
import { RetrieveCommandInput, RetrieveCommandOutput } from "../commands/RetrieveCommand";
import { BedrockAgentRuntimePaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateRetrieve: (config: BedrockAgentRuntimePaginationConfiguration, input: RetrieveCommandInput, ...rest: any[]) => Paginator<RetrieveCommandOutput>;
