import { Paginator } from "@smithy/types";
import {
  RetrieveCommandInput,
  RetrieveCommandOutput,
} from "../commands/RetrieveCommand";
import { BedrockAgentRuntimePaginationConfiguration } from "./Interfaces";
export declare const paginateRetrieve: (
  config: BedrockAgentRuntimePaginationConfiguration,
  input: RetrieveCommandInput,
  ...rest: any[]
) => Paginator<RetrieveCommandOutput>;
