import { Paginator } from "@smithy/types";
import {
  RerankCommandInput,
  RerankCommandOutput,
} from "../commands/RerankCommand";
import { BedrockAgentRuntimePaginationConfiguration } from "./Interfaces";
export declare const paginateRerank: (
  config: BedrockAgentRuntimePaginationConfiguration,
  input: RerankCommandInput,
  ...rest: any[]
) => Paginator<RerankCommandOutput>;
