import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  BedrockAgentRuntimeClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../BedrockAgentRuntimeClient";
import {
  UpdateSessionRequest,
  UpdateSessionResponse,
} from "../models/models_0";
export { __MetadataBearer };
export { $Command };
export interface UpdateSessionCommandInput extends UpdateSessionRequest {}
export interface UpdateSessionCommandOutput
  extends UpdateSessionResponse,
    __MetadataBearer {}
declare const UpdateSessionCommand_base: {
  new (
    input: UpdateSessionCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    UpdateSessionCommandInput,
    UpdateSessionCommandOutput,
    BedrockAgentRuntimeClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: UpdateSessionCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    UpdateSessionCommandInput,
    UpdateSessionCommandOutput,
    BedrockAgentRuntimeClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class UpdateSessionCommand extends UpdateSessionCommand_base {
  protected static __types: {
    api: {
      input: UpdateSessionRequest;
      output: UpdateSessionResponse;
    };
    sdk: {
      input: UpdateSessionCommandInput;
      output: UpdateSessionCommandOutput;
    };
  };
}
